# API reference

The reference below is generated from the public Python API. Functions and classes inherit docstrings directly from the source code to keep behavior descriptions synchronized.

## Core parcellator

::: parcellate.parcellation.volume

## Metrics

::: parcellate.metrics.base

::: parcellate.metrics.volume

## Utilities

::: parcellate.utils.image
